==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/EventQueueEntrySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.EventQueueEntry;
import io.ciera.tool.sql.ooaofooa.instance.EventQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.PendingEventSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.EventQueueEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.PendingEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventQueueEntrySetImpl extends InstanceSet<EventQueueEntrySet,EventQueueEntry> implements EventQueueEntrySet {

    // attributes
    @Override
    public void setExecution_Engine_ID( UniqueId ref_Execution_Engine_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setExecution_Engine_ID( ref_Execution_Engine_ID );
    }
    @Override
    public void setNext_Event_Queue_Entry_ID( UniqueId ref_Next_Event_Queue_Entry_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setNext_Event_Queue_Entry_ID( ref_Next_Event_Queue_Entry_ID );
    }
    @Override
    public void setEvent_Queue_Entry_ID( UniqueId m_Event_Queue_Entry_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setEvent_Queue_Entry_ID( m_Event_Queue_Entry_ID );
    }
    @Override
    public void setEvent_ID( UniqueId ref_Event_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setEvent_ID( ref_Event_ID );
    }


    // selections
    @Override
    public ComponentInstanceSet R2944_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( EventQueueEntry eventqueueentry : this ) componentinstanceset.add( eventqueueentry.R2944_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public PendingEventSet R2944_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( EventQueueEntry eventqueueentry : this ) pendingeventset.add( eventqueueentry.R2944_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public EventQueueEntrySet R2945_follows_EventQueueEntry() throws XtumlException {
        EventQueueEntrySet eventqueueentryset = new EventQueueEntrySetImpl();
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentryset.add( eventqueueentry.R2945_follows_EventQueueEntry() );
        return eventqueueentryset;
    }
    @Override
    public EventQueueEntrySet R2945_precedes_EventQueueEntry() throws XtumlException {
        EventQueueEntrySet eventqueueentryset = new EventQueueEntrySetImpl();
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentryset.add( eventqueueentry.R2945_precedes_EventQueueEntry() );
        return eventqueueentryset;
    }


    @Override
    public EventQueueEntry nullElement() {
        return EventQueueEntryImpl.EMPTY_EVENTQUEUEENTRY;
    }

    @Override
    public EventQueueEntrySet emptySet() {
      return new EventQueueEntrySetImpl();
    }

    @Override
    public EventQueueEntrySet value() {
        return this;
    }

    @Override
    public List<EventQueueEntry> elements() {
        return Arrays.asList(toArray(new EventQueueEntry[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/EventQueueEntrySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.EventQueueEntry;
import io.ciera.tool.sql.ooaofooa.instance.EventQueueEntrySet;
import io.ciera.tool.sql.ooaofooa.instance.PendingEventSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.EventQueueEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.instance.impl.PendingEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventQueueEntrySetImpl extends InstanceSet<EventQueueEntrySet,EventQueueEntry> implements EventQueueEntrySet {

    public EventQueueEntrySetImpl() {
    }

    public EventQueueEntrySetImpl(Comparator<? super EventQueueEntry> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setEvent_ID( UniqueId ref_Event_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setEvent_ID( ref_Event_ID );
    }
    @Override
    public void setExecution_Engine_ID( UniqueId ref_Execution_Engine_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setExecution_Engine_ID( ref_Execution_Engine_ID );
    }
    @Override
    public void setEvent_Queue_Entry_ID( UniqueId m_Event_Queue_Entry_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setEvent_Queue_Entry_ID( m_Event_Queue_Entry_ID );
    }
    @Override
    public void setNext_Event_Queue_Entry_ID( UniqueId ref_Next_Event_Queue_Entry_ID ) throws XtumlException {
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentry.setNext_Event_Queue_Entry_ID( ref_Next_Event_Queue_Entry_ID );
    }


    // selections
    @Override
    public ComponentInstanceSet R2944_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( EventQueueEntry eventqueueentry : this ) componentinstanceset.add( eventqueueentry.R2944_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public PendingEventSet R2944_PendingEvent() throws XtumlException {
        PendingEventSet pendingeventset = new PendingEventSetImpl();
        for ( EventQueueEntry eventqueueentry : this ) pendingeventset.add( eventqueueentry.R2944_PendingEvent() );
        return pendingeventset;
    }
    @Override
    public EventQueueEntrySet R2945_follows_EventQueueEntry() throws XtumlException {
        EventQueueEntrySet eventqueueentryset = new EventQueueEntrySetImpl();
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentryset.add( eventqueueentry.R2945_follows_EventQueueEntry() );
        return eventqueueentryset;
    }
    @Override
    public EventQueueEntrySet R2945_precedes_EventQueueEntry() throws XtumlException {
        EventQueueEntrySet eventqueueentryset = new EventQueueEntrySetImpl();
        for ( EventQueueEntry eventqueueentry : this ) eventqueueentryset.add( eventqueueentry.R2945_precedes_EventQueueEntry() );
        return eventqueueentryset;
    }


    @Override
    public EventQueueEntry nullElement() {
        return EventQueueEntryImpl.EMPTY_EVENTQUEUEENTRY;
    }

    @Override
    public EventQueueEntrySet emptySet() {
      return new EventQueueEntrySetImpl();
    }

    @Override
    public EventQueueEntrySet emptySet(Comparator<? super EventQueueEntry> comp) {
      return new EventQueueEntrySetImpl(comp);
    }

    @Override
    public EventQueueEntrySet value() {
        return this;
    }

    @Override
    public List<EventQueueEntry> elements() {
        return Arrays.asList(toArray(new EventQueueEntry[0]));
    }

}
